/*
@file    FT800_config.c
@brief   Contains hardware abstraction functions for using the FT8xx
@version 2.4
@date    2016-06-24
@author  Rudolph Riedel

This file needs to be renamed to FT800_config.cpp for use with Arduino. 

@section History

2.2
- extracted from FT800_commands.c
- added ft800_pdn_set() and ft800_pdn_clear()
- replaced spi_flash_write() with fetch_flash_byte()

2.3
- added set of functions for Arduino

2.4
- switched from custom AVR8 to standard __AVR__ symbol to automatically generate plattform specific code

*/

#include "FT800_config.h"

#ifndef ARDUINO

#if defined (__GNUC__) && defined (__AVR__)

void ft800_cs_set(void)
{
	FT_CS_PORT &= ~FT_CS;	// cs low
}


void ft800_cs_clear(void)
{
	FT_CS_PORT |= FT_CS;	// cs high
}


void ft800_pdn_set(void)
{
	FT_PDN_PORT &= ~FT_PDN;	// Power-Down low
}


void ft800_pdn_clear(void)
{
	FT_PDN_PORT |= FT_PDN;	// Power-Down high
}


void spi_transmit(uint8_t data)
{
	SPDR = data; // Start transmission
	while(!(SPSR & (1<<SPIF))); // Wait for transmission to complete - 1s @ 8MHz SPI-Clock
}


uint8_t spi_receive(uint8_t data)
{
	SPDR = data; // Start transmission
	while(!(SPSR & (1<<SPIF))); // Wait for transmission to complete - 1s @ 8MHz SPI-CLock
	return SPDR;
}


uint8_t fetch_flash_byte(const uint8_t *data)
{
	return(pgm_read_byte_far(data));
}


#endif // AVR

#endif // !Arduino


#ifdef ARDUINO

void ft800_cs_set(void)
{
	SPI.setDataMode(SPI_MODE0);
	digitalWrite(FT_CS, LOW);
}


void ft800_cs_clear(void)
{
	digitalWrite(FT_CS, HIGH);
}

void ft800_pdn_set(void)
{
	digitalWrite(FT_PDN, LOW);	// Power-Down low
}


void ft800_pdn_clear(void)
{
	digitalWrite(FT_PDN, HIGH);	// Power-Down high
}

void spi_transmit(uint8_t data)
{
	SPI.transfer(data);
}


uint8_t spi_receive(uint8_t data)
{
	return SPI.transfer(data);
}

uint8_t fetch_flash_byte(const uint8_t *data)
{
	return(pgm_read_byte_near(data));
}

#endif